netapp_ontap.models.shelf_ports_remote API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_ports_remote`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfPortsRemoteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfPortsRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `chassis: str GET POST PATCH`

    The chassis field of the shelf_ports_remote.

  `device: str GET POST PATCH`

    The device field of the shelf_ports_remote.

  `mac_address: str GET POST PATCH`

    The mac_address field of the shelf_ports_remote.

  `phy: str GET POST PATCH`

    The phy field of the shelf_ports_remote.

    Example: 12

  `port: str GET POST PATCH`

    The port field of the shelf_ports_remote.

  `wwn: str GET POST PATCH`

    The wwn field of the shelf_ports_remote.

    Example: 50000D1703544B80